import { useEffect, useState } from "preact/hooks";
import { createPortal } from "preact/compat";
import type { FunctionComponent } from "preact";

interface IProps {
  className?: string;
  el?: string;
}

export const Portal: FunctionComponent<IProps> = (
  { children, className = "root-portal", el = "div" },
) => {
  const [container, setContainer] = useState<HTMLElement>();

  useEffect(() => {
    const container = document.createElement(el);
    container.classList.add(className);
    document.body.appendChild(container);
    setContainer(container);
    return () => {
      document.body.removeChild(container);
    };
  }, [className, el]);

  return container ? createPortal(children, container) : <></>;
};
